@@ -30,17 +30,47 @@ warnings.filterwarnings("ignore")
 
 class accuinsight(Common):
     def __init__(self):
-        global feature_name
-        feature_name = None
+        global feature_name, alarm, alarm_api, message_param, thresholds
         super().__init__()
 
+        feature_name = None
+        alarm = self.workspace_alarm
+        alarm_api = self.workspace_alarm_api
+
     def get_file(self, storage_json_file_name=None):
         global save_path, StorageInfo, target_name
         save_path, StorageInfo, target_name = super().get_file(storage_json_file_name)
 
     def set_features(self, feature_names):
+        global feature_name
         feature_name = super().set_features(feature_names)
 
+    def set_slack(self, hook_url=None):
+        alarm.notifiers['slack'] = hook_url
+
+    def unset_slack(self):
+        if 'slack' in alarm.notifiers.keys():
+            del alarm.notifiers['slack']
+
+    def set_mail(self, address=None):
+        alarm.notifiers['mail'] = address
+
+    def unset_mail(self):
+        if 'mail' in alarm.notifiers.keys():
+            del alarm.notifiers['mail']
+
+    def send_message(self, message=None, thresholds=None):
+        global message_param
+
+        if thresholds:
+            raise ValueError("ML 모델의 경우 'thresholds'를 사용한 alarm 기능을 사용할 수 없습니다. message 인수를 사용해 주세요.")
+        else:
+            message_param = message
+
+    def unset_message(self):
+        global message_param
+        message_param = None
+
     class add_experiment(object):
         def __init__(self, model_name, *args, model_monitor=False):
             self.shap_on = model_monitor
@@ -229,6 +259,14 @@ class accuinsight(Common):
             delta_ts = end_time - start_time
 
             clear_runs(start_time, end_time, delta_ts)
+
+            accuinsight._send_message(metric=None,
+                                      current_value=None,
+                                      message=message_param,
+                                      thresholds=None,
+                                      alarm_object=alarm,
+                                      alarm_api=alarm_api)
+
             env_value = get_os_env('ENV')
             modeler_rest = LifecycleRestApi(env_value[LcConst.BACK_END_API_URL],
                                             env_value[LcConst.BACK_END_API_PORT],
